      SUBROUTINE SUBDLOGH(dlogne,amlat,sg,rz,dh)
C....................................................................................Mar. 2011
C Model of dh=dlog_hmF2, in terms of log10(NeF2/NmF2), abs(MLAT), deg., SG=Sday, Rz
C
C  (1) 2 levels of solar activity: Rz= 20,  120
C  (2) 5th order polinomial for geomagnetic latitudes (N=S):0,10,20,30,40,50,60,70,80,90.
C  (4) 4 seasonal grids: 1 equinox(sg=90deg), 2 summer (sg=180), 
C                        3 equinox (sg=270), 4 winter(sg=360)
C
		DIMENSION YY(3),XX(3)
	&,BR(6,3,2) ! 6  beta coef, 3 seasons, 2 Rz levels
	&,AR(6,3,2) ! 6 alpha coef, 3 seasons, 2 Rz levels
	 	COMMON /BLA1B1/ALPHA,BETA

	 	DATA rad/0.01745329/
	 DATA AR/
C Polinomial <alpha> coefficients A1, A2, A3, A4, A5, A6 for Rz=20:
C Equinox:
	* 708.327,-1527.953,  1103.833, -304.492,  34.062,  -4.422
C Summer	
     *,-64.5256, 254.8368, -291.2572,  97.7416,  8.4343, -3.9076
C Winter:
	*,99.9013, -61.4048,-120.2377,  92.2898,  -4.6909, -2.9850
C Polinomial <alpha> coefficients A1, A2, A3, A4, A5, A6 for Rz=120:
C Equinox:
	*,271.9513,-261.3368,-200.8858, 249.5253, -47.7269,  -2.0143
C Summer		
	*,-422.818,1012.842, -890.418,  347.730,  -54.262,    1.859
C Winter:     	
	*,145.3128,-128.5541,-131.3022, 148.7525, -29.4966,  -1.1053/
	 DATA BR/
C Polinomial <beta> coefficients B1, B2, B3, B4, B5, B6 for Rz=20:
C Equinox:
	* 3.0154,  -6.4793,   4.8852,  -1.3451,   0.0490,  -0.1681
C Summer		
     *,-5.8795,  17.7169, -18.0480,   7.5002,  -1.1586,  -0.1527
C Winter:     	
	*,24.7256, -57.3807,  45.7255, -13.6397,   0.9003,  -0.1040
C Polinomial <beta> coefficients B1, B2, B3, B4, B5, B6 for Rz=120:     	
C Equinox:  
     *,10.3154, -23.8605,  19.0188,  -5.5255,   0.2329,  -0.1574
C Summer		
	*,-3.3154,   9.3716,  -9.1249,   3.2476,  -0.1863,  -0.2255
C Winter:
	*,12.9551, -28.8785,  22.2281,  -6.2295,   0.1901,  -0.0897/
C
C----------------------------------------------------------------------
C
		ABMLAT=ABS(AMLAT)/100.
	dlogne=dlogne*1000.
	IR=1    ! LSA
	xi=abmlat
  25	CONTINUE
C
      DO LS=1,3
	B1=BR(6,LS,IR)
	B2=BR(5,LS,IR)
	B3=BR(4,LS,IR)
	B4=BR(3,LS,IR)
	B5=BR(2,LS,IR)
	B6=BR(1,LS,IR)
	YY(LS)=B1+xi*(B2+xi*(B3+xi*(B4+xi*(B5+xi*(B6+xi)))))
	A1=AR(6,LS,IR)
	A2=AR(5,LS,IR)
	A3=AR(4,LS,IR)
	A4=AR(3,LS,IR)
	A5=AR(2,LS,IR)
	A6=AR(1,LS,IR)
	XX(LS)=A1+xi*(A2+xi*(A3+xi*(A4+xi*(A5+xi*(A6+xi)))))
	ENDDO
C Apply seasonal interpolation
	p0=(2.*YY(1)+YY(2)+YY(3))/4.
	p1=(YY(3)-YY(2))/2.
	p2=(YY(2)+YY(3)-2.*YY(1))/4.
	YB=p0+p1*cos(sg*rad)+p2*cos(2.*sg*rad)
	r0=(2.*XX(1)+XX(2)+XX(3))/4.
	r1=(XX(3)-XX(2))/2.
	r2=(XX(2)+XX(3)-2.*XX(1))/4.
	XA=r0+r1*cos(sg*rad)+r2*cos(2.*sg*rad)
C
	IF (IR.eq.2) THEN
	goto 26
	             ELSE  
	IR=2
	YB1=YB
	XA1=XA
	goto 25
	             ENDIF
   26 CONTINUE
C Solar activity interpolation
      alpha=XA1+(XA-XA1)*(RZ-20.)/100.
	beta=YB1+(YB-YB1)*(RZ-20.)/100.
C
	DH=(beta*dlogne+alpha)/1000.
	RETURN
	END